@@ -75,6 +75,7 @@ class Cadet(SolverBase):
     cadetInterface
     """
     timeout = UnsignedFloat()
+    _force_constant_flow_rate = False
 
     def __init__(self, install_path=None, temp_dir=None, *args, **kwargs):
         self.install_path = install_path
@@ -327,8 +328,8 @@ class Cadet(SolverBase):
         self,
         process,
         cadet,
-        time_elapsed,
-        return_information,
+        time_elapsed=None,
+        return_information=None,
         ):
         """Saves the simulated results for each unit into the dictionary
         concentration_record for the complete simulation and splitted into each
@@ -362,7 +363,15 @@ class Cadet(SolverBase):
         -----
         !!! Implement method to read .h5 files that have no process associated.
         """
+        if time_elapsed is None:
+            time_elapsed = cadet.root.meta.time_sim
         time = process.time
+        if return_information is None:
+            exit_flag = None
+            exit_message = None
+        else:
+            exit_flag = return_information.returncode
+            exit_message = return_information.stderr.decode()
 
         solution = Dict()
         from collections import defaultdict
@@ -449,8 +458,8 @@ class Cadet(SolverBase):
         results = SimulationResults(
             solver_name = str(self),
             solver_parameters = dict(),
-            exit_flag = return_information.returncode,
-            exit_message = return_information.stderr.decode(),
+            exit_flag = exit_flag,
+            exit_message = exit_message,
             time_elapsed = time_elapsed,
             process_name = process.name,
             process_config = process.config,
@@ -494,7 +503,11 @@ class Cadet(SolverBase):
         """Config branch /input/model/connections
         """
         model_connections = Dict()
-        model_connections['CONNECTIONS_INCLUDE_DYNAMIC_FLOW'] = 1
+        if self._force_constant_flow_rate:
+            model_connections['CONNECTIONS_INCLUDE_DYNAMIC_FLOW'] = 0
+        else: 
+            model_connections['CONNECTIONS_INCLUDE_DYNAMIC_FLOW'] = 1
+
         index = 0
 
         section_states = process.flow_rate_section_states
@@ -546,7 +559,11 @@ class Cadet(SolverBase):
                     table[enum].append(int(destination_index))
                     table[enum].append(-1)
                     table[enum].append(-1)
-                    table[enum] += flow_rate.tolist()
+                    Q = flow_rate.tolist()
+                    if self._force_constant_flow_rate:
+                        table[enum] += [Q[0]]
+                    else:
+                        table[enum] += Q
                     enum += 1
 
         ls = []
@@ -765,12 +782,12 @@ class Cadet(SolverBase):
 
         solver_sections.nsec = process._n_cycles * process.n_sections
         solver_sections.section_times = [
-            round((cycle*process.cycle_time + evt),1)
+            cycle*process.cycle_time + evt
             for cycle in range(process._n_cycles)
             for evt in process.section_times[0:-1]
         ]
         solver_sections.section_times.append(
-            round(process._n_cycles * process.cycle_time,1)
+            process._n_cycles * process.cycle_time
         )
         solver_sections.section_continuity = [0] * (solver_sections.nsec - 1)
 
@@ -812,7 +829,14 @@ class ModelSolverParametersGroup(ParametersGroup):
     MAX_KRYLOV = UnsignedInteger(default=0)
     MAX_RESTARTS = UnsignedInteger(default=10)
     SCHUR_SAFETY = UnsignedFloat(default=1e-8)
-    _parameters = ['GS_TYPE', 'MAX_KRYLOV', 'MAX_RESTARTS', 'SCHUR_SAFETY']
+    LINEAR_SOLUTION_MODE = UnsignedInteger(default=2, ub=2)
+    _parameters = [
+        'GS_TYPE', 
+        'MAX_KRYLOV',
+        'MAX_RESTARTS',
+        'SCHUR_SAFETY',
+        'LINEAR_SOLUTION_MODE',
+    ]
 
 unit_parameters_map = {
     'GeneralRateModel': {
@@ -967,7 +991,7 @@ adsorption_parameters_map = {
             'IS_KINETIC' : 'is_kinetic',
             'MCL_KA': 'adsorption_rate',
             'MCL_KD': 'desorption_rate',
-            'MCL_QMAX': 'saturation_capacity'
+            'MCL_QMAX': 'capacity'
         },
     },
     'BiLangmuir': {
@@ -976,7 +1000,7 @@ adsorption_parameters_map = {
             'IS_KINETIC' : 'is_kinetic',
             'MCBL_KA': 'adsorption_rate',
             'MCBL_KD': 'desorption_rate',
-            'MCBL_QMAX': 'saturation_capacity'
+            'MCBL_QMAX': 'capacity'
         },
     },
     'StericMassAction': {
@@ -998,7 +1022,7 @@ adsorption_parameters_map = {
             'IS_KINETIC' : 'is_kinetic',
             'MCAL_KA': 'adsorption_rate',
             'MCAL_KD': 'desorption_rate',
-            'MCAL_QMAX': 'saturation_capacity',
+            'MCAL_QMAX': 'capacity',
             'MCAL_ANTILANGMUIR': 'antilangmuir'
         },
     },
@@ -1008,7 +1032,7 @@ adsorption_parameters_map = {
             'IS_KINETIC' : 'is_kinetic',
             'MPM_KA': 'adsorption_rate',
             'MPM_KD': 'desorption_rate',
-            'MPM_QMAX': 'maximum_adsorption_capacity',
+            'MPM_QMAX': 'capacity',
             'MPM_BETA': 'ion_exchange_characteristic',
             'MPM_GAMMA': 'hydrophobicity'
         },
@@ -1019,7 +1043,7 @@ adsorption_parameters_map = {
             'IS_KINETIC' : 'is_kinetic',
             'EMPM_KA': 'adsorption_rate',
             'EMPM_KD': 'desorption_rate',
-            'EMPM_QMAX': 'maximum_adsorption_capacity',
+            'EMPM_QMAX': 'capacity',
             'EMPM_BETA': 'ion_exchange_characteristic',
             'EMPM_GAMMA': 'hydrophobicity',
             'EMPM_COMP_MODE': 'component_mode',
